@@ -92,8 +92,9 @@ nice_mod <- function(data,
                      ...) {
   check_col_names(data, c(predictor, response, moderator, moderator2, covariates))
   rlang::check_installed("effectsize",
-                         version = get_dep_version("effectsize"),
-                         reason = "for this function.")
+    version = get_dep_version("effectsize"),
+    reason = "for this function."
+  )
 
   if (!missing(b.label)) {
     message(paste(
@@ -103,6 +104,15 @@ nice_mod <- function(data,
     ))
   }
 
+  data <- data %>%
+    dplyr::select(dplyr::any_of(c(
+      response,
+      predictor,
+      moderator,
+      moderator2,
+      covariates
+    )))
+
   if (data_is_standardized(data)) {
     b.label <- "B"
   } else if (isTRUE(standardize)) {
